==> react-native-0.17.0.tgz: package/Libraries/Utilities/CSSVarConfig.js <==
/**
 * Copyright 2004-present Facebook. All Rights Reserved.
 *
 * @providesModule CSSVarConfig
 */
'use strict';

// this a partial list of the contants in CSSConstants:: from PHP that are applicable to mobile

module.exports = {
  'fbui-accent-blue': '#5890ff',
  'fbui-blue-90': '#4e69a2',
  'fbui-blue-80': '#627aad',
  'fbui-blue-70': '#758ab7',
  'fbui-blue-60': '#899bc1',
  'fbui-blue-50': '#9daccb',
  'fbui-blue-40': '#b1bdd6',
  'fbui-blue-30': '#c4cde0',
  'fbui-blue-20': '#d8deea',
  'fbui-blue-10': '#ebeef4',
  'fbui-blue-5': '#f5f7fa',
  'fbui-blue-2': '#fbfcfd',
  'fbui-blueblack-90': '#06090f',
  'fbui-blueblack-80': '#0c121e',
  'fbui-blueblack-70': '#121b2e',
  'fbui-blueblack-60': '#18243d',
  'fbui-blueblack-50': '#1e2d4c',
  'fbui-blueblack-40': '#23355b',
  'fbui-blueblack-30': '#293e6b',
  'fbui-blueblack-20': '#2f477a',
  'fbui-blueblack-10': '#355089',
  'fbui-blueblack-5': '#385490',
  'fbui-blueblack-2': '#3a5795',
  'fbui-bluegray-90': '#080a10',
  'fbui-bluegray-80': '#141823',
  'fbui-bluegray-70': '#232937',
  'fbui-bluegray-60': '#373e4d',
  'fbui-bluegray-50': '#4e5665',
  'fbui-bluegray-40': '#6a7180',
  'fbui-bluegray-30': '#9197a3',
  'fbui-bluegray-20': '#bdc1c9',
  'fbui-bluegray-10': '#dcdee3',
  'fbui-bluegray-5': '#e9eaed',
  'fbui-bluegray-2': '#f6f7f8',
  'fbui-gray-90': '#191919',
  'fbui-gray-80': '#333333',
  'fbui-gray-70': '#4c4c4c',
  'fbui-gray-60': '#666666',
  'fbui-gray-50': '#7f7f7f',
  'fbui-gray-40': '#999999',
  'fbui-gray-30': '#b2b2b2',
  'fbui-gray-20': '#cccccc',
  'fbui-gray-10': '#e5e5e5',
  'fbui-gray-5': '#f2f2f2',
  'fbui-gray-2': '#fafafa',
  'fbui-red': '#da2929',
  'fbui-error': '#ce0d24',
  'x-mobile-dark-text': '#4e5665',
  'x-mobile-medium-text': '#6a7180',
  'x-mobile-light-text': '#9197a3',
  'x-mobile-base-wash': '#dcdee3',
};

==> react-native-0.20.0.tgz: package/Libraries/Utilities/CSSVarConfig.js <==
/**
 * Copyright 2004-present Facebook. All Rights Reserved.
 *
 * @providesModule CSSVarConfig
 */
'use strict';

// this a partial list of the constants in CSSConstants:: from PHP that are applicable to mobile

module.exports = {
  'fbui-accent-blue': '#5890ff',
  'fbui-blue-90': '#4e69a2',
  'fbui-blue-80': '#627aad',
  'fbui-blue-70': '#758ab7',
  'fbui-blue-60': '#899bc1',
  'fbui-blue-50': '#9daccb',
  'fbui-blue-40': '#b1bdd6',
  'fbui-blue-30': '#c4cde0',
  'fbui-blue-20': '#d8deea',
  'fbui-blue-10': '#ebeef4',
  'fbui-blue-5': '#f5f7fa',
  'fbui-blue-2': '#fbfcfd',
  'fbui-blueblack-90': '#06090f',
  'fbui-blueblack-80': '#0c121e',
  'fbui-blueblack-70': '#121b2e',
  'fbui-blueblack-60': '#18243d',
  'fbui-blueblack-50': '#1e2d4c',
  'fbui-blueblack-40': '#23355b',
  'fbui-blueblack-30': '#293e6b',
  'fbui-blueblack-20': '#2f477a',
  'fbui-blueblack-10': '#355089',
  'fbui-blueblack-5': '#385490',
  'fbui-blueblack-2': '#3a5795',
  'fbui-bluegray-90': '#080a10',
  'fbui-bluegray-80': '#141823',
  'fbui-bluegray-70': '#232937',
  'fbui-bluegray-60': '#373e4d',
  'fbui-bluegray-50': '#4e5665',
  'fbui-bluegray-40': '#6a7180',
  'fbui-bluegray-30': '#9197a3',
  'fbui-bluegray-20': '#bdc1c9',
  'fbui-bluegray-10': '#dcdee3',
  'fbui-bluegray-5': '#e9eaed',
  'fbui-bluegray-2': '#f6f7f8',
  'fbui-gray-90': '#191919',
  'fbui-gray-80': '#333333',
  'fbui-gray-70': '#4c4c4c',
  'fbui-gray-60': '#666666',
  'fbui-gray-50': '#7f7f7f',
  'fbui-gray-40': '#999999',
  'fbui-gray-30': '#b2b2b2',
  'fbui-gray-20': '#cccccc',
  'fbui-gray-10': '#e5e5e5',
  'fbui-gray-5': '#f2f2f2',
  'fbui-gray-2': '#fafafa',
  'fbui-red': '#da2929',
  'fbui-error': '#ce0d24',
  'x-mobile-dark-text': '#4e5665',
  'x-mobile-medium-text': '#6a7180',
  'x-mobile-light-text': '#9197a3',
  'x-mobile-base-wash': '#dcdee3',
};
